## The Core Principles of Crypto Currency

1. Technobabble on the outside, [naturally occuring ponzi scheme](https://openknowledge.worldbank.org/handle/10986/19358) on the inside

2. All news is good news

...especially when the news is about failing to meet your stated objectives.

3. The future is just around the corner

...even if it has been so for the past decade.

4. The more outrageous the claim, the harder it is to refute

5. In case of emergency, betray your core principles
